@@ -4,7 +4,7 @@ from itertools import groupby
 
 
 from .api import SquadApi
-from squad_client.exceptions import InvalidSquadObject
+from squad_client.exceptions import InvalidSquadObject, InvalidSquadLookup
 from squad_client.utils import first, parse_test_name, parse_metric_name, to_json
 from squad_client import settings
 
@@ -137,6 +137,9 @@ class Squad(SquadObject):
     def tests(self, count=DEFAULT_COUNT, **filters):
         return self.__fetch__(Test, filters, count)
 
+    def metrics(self, count=DEFAULT_COUNT, **filters):
+        return self.__fetch__(Metric, filters, count)
+
     def suites(self, count=DEFAULT_COUNT, **filters):
         return self.__fetch__(Suite, filters, count)
 
@@ -236,9 +239,35 @@ class Project(SquadObject):
         objects = self.builds(count=1, **filters)
         return first(objects)
 
+    def suites(self, count=DEFAULT_COUNT, **filters):
+        filters.update({'project': self.id})
+        return self.__fetch__(Suite, filters, count)
+
+    def suite(self, suite_slug):
+        filters = {'slug': suite_slug}
+        objects = self.suites(count=1, **filters)
+        return first(objects)
+
     def __repr__(self):
         return self.slug
 
+    @staticmethod
+    def compare_builds(baseline_id, build_id):
+        try:
+            int(baseline_id)
+            int(build_id)
+        except ValueError:
+            raise ValueError("IDs must be valid integers")
+        baseline = Build(baseline_id)
+        to_compare = Build(build_id)
+        if baseline.id and to_compare.id:
+            proj_id = baseline.project.split("/")[-2]
+            if proj_id != to_compare.project.split("/")[-2]:
+                raise InvalidSquadLookup("Argument builds must belong to same project")
+            url = ''.join([Project.endpoint, str(proj_id), '/compare_builds'])
+            params = {'baseline': baseline_id, 'to_compare': build_id}
+            return SquadApi.get(url, params).json()
+
 
 class Build(SquadObject):
 
@@ -315,7 +344,8 @@ class MetricSuite:
 
 
 class Metric(SquadObject):
-    pass
+    endpoint = '/api/metrics/'
+    attrs = ['id', 'name', 'short_name', 'measurement_list', 'result', 'is_outlier', 'test_run', 'suite', 'metadata']
 
 
 class TestRunStatus(SquadObject):
@@ -365,7 +395,7 @@ class TestRun(SquadObject):
 
     def metrics(self, count=ALL, **filters):
         if self.__metrics__ is None and hasattr(self, 'id') and self.id is not None:
-            Metric.endpoint = '%s%d/metrics' % (self.endpoint, self.id)
+            filters.update({'test_run': self.id})
             self.__metrics__ = self.__fetch__(Metric, filters, count)
         return self.__metrics__
 
@@ -413,7 +443,7 @@ class TestRun(SquadObject):
         return self.__summary__
 
     def statuses(self, count=ALL, **filters):
-        TestRunStatus.endpoint = '%s%d/status' % (self.endpoint, self.id)
+        TestRunStatus.endpoint = '/'.join([TestRun.endpoint[:-1], str(self.id), 'status'])
         return self.__fetch__(TestRunStatus, filters, count)
 
 
